#
# Conditional build:
%bcond_without	apidocs		# API documentation build
%bcond_with	apt		# Debian/APT support
%bcond_without	qt		# Qt library (libappstream-qt)
%bcond_without	vala		# Vala API (VAPI)

Summary:	AppStream-Core library and tools
Summary(pl.UTF-8):	Biblioteka i narzędzia AppStream-Core
Name:		AppStream
Version:	0.11.7
Release:	1
License:	LGPL v2.1+
Group:		Libraries
Source0:	https://www.freedesktop.org/software/appstream/releases/%{name}-%{version}.tar.xz
# Source0-md5:	9ebc5f5dff51ee6f4d15fdadd782caa7
Patch0:		%{name}-meson.patch
URL:		https://www.freedesktop.org/wiki/Distributions/AppStream/
BuildRequires:	docbook-style-xsl-nons
BuildRequires:	gettext-tools
BuildRequires:	glib2-devel >= 1:2.46
BuildRequires:	gobject-introspection-devel
BuildRequires:	itstool
BuildRequires:	libstdc++-devel >= 6:4.9
BuildRequires:	libstemmer-devel
BuildRequires:	libxml2-devel >= 2.0
BuildRequires:	libxslt-progs
BuildRequires:	meson >= 0.42
BuildRequires:	pkgconfig
BuildRequires:	protobuf-devel
BuildRequires:	rpmbuild(macros) >= 1.727
BuildRequires:	tar >= 1:1.22
%{?with_vala:BuildRequires:	vala}
BuildRequires:	xmlto
BuildRequires:	xz
BuildRequires:	yaml-devel >= 0.1
%if %{with qt}
BuildRequires:	Qt5Core-devel >= 5.0
BuildRequires:	Qt5Test-devel >= 5.0
BuildRequires:	qt5-build >= 5.0
BuildRequires:	qt5-qmake >= 5.0
%endif
%if %{with apidocs}
BuildRequires:	gtk-doc
BuildRequires:	publican
BuildRequires:	python3
%endif
Requires:	glib2 >= 1:2.46
Obsoletes:	PackageKit-plugin-appstream
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

%description
AppStream-Core library and tools to access the AppStream component
database.

%description -l pl.UTF-8
Biblioteka i narzędzia AppStream-Core służące do dostępu do bazy
danych komponentu AppStream.

%package devel
Summary:	Header files for AppStream library
Summary(pl.UTF-8):	Pliki nagłówkowe biblioteki AppStream
Group:		Development/Libraries
Requires:	%{name} = %{version}-%{release}
Requires:	glib2-devel >= 1:2.46

%description devel
Header files for AppStream library.

%description devel -l pl.UTF-8
Pliki nagłówkowe biblioteki AppStream.

%package apidocs
Summary:	AppStream API documentation
Summary(pl.UTF-8):	Dokumentacja API biblioteki AppStream
Group:		Documentation
%if "%{_rpmversion}" >= "5"
BuildArch:	noarch
%endif

%description apidocs
API documentation for AppStream library.

%description apidocs -l pl.UTF-8
Dokumentacja API biblioteki AppStream.

%package qt
Summary:	AppstreamQt library
Summary(pl.UTF-8):	Biblioteka AppstreamQt
Group:		Libraries
Requires:	Qt5Core >= 5.0

%description qt
AppstreamQt library.

%description qt -l pl.UTF-8
Biblioteka AppstreamQt.

%package qt-devel
Summary:	Header files for AppstreamQt library
Summary(pl.UTF-8):	Pliki nagłówkowe biblioteki AppstreamQt
Group:		Libraries
Requires:	%{name}-qt = %{version}-%{release}
Requires:	Qt5Core-devel >= 5.0

%description qt-devel
Header files for AppstreamQt library.

%description qt-devel -l pl.UTF-8
Pliki nagłówkowe biblioteki AppstreamQt.

%package -n gettext-its-metainfo
Summary:	AppStream metainfo ITS data for gettext tools
Summary(pl.UTF-8):	Dane ITS AppStream metainfo dla narzędzi gettext
Group:		Development/Tools
Requires:	gettext-tools >= 0.19

%description -n gettext-its-metainfo
AppStream metainfo ITS data for gettext tools.

%description -n gettext-its-metainfo -l pl.UTF-8
Dane ITS AppStream metainfo dla narzędzi gettext.

%package -n vala-appstream
Summary:	Vala API for AppStream library
Summary(pl.UTF-8):	API języka Vala do biblioteki AppStream
Group:		Development/Libraries
Requires:	%{name}-devel = %{version}-%{release}
Requires:	vala
%if "%{_rpmversion}" >= "5"
BuildArch:	noarch
%endif

%description -n vala-appstream
Vala API for AppStream library.

%description -n vala-appstream -l pl.UTF-8
API języka Vala do biblioteki AppStream.

%prep
%setup -q
%patch0 -p1

%build
%meson build \
	%{?with_apidocs:-Ddocs=true} \
	%{?with_apt:-Dapt-support=true} \
	%{?with_qt:-Dqt=true} \
	-Dgir=true \
	-Dstemming=true \
	%{?with_vala:-Dvapi=true}

%meson_build -C build

%install
rm -rf $RPM_BUILD_ROOT

%meson_install -C build

install -d $RPM_BUILD_ROOT%{_docdir}
%{__mv} $RPM_BUILD_ROOT%{_datadir}/gtk-doc $RPM_BUILD_ROOT%{_docdir}

%find_lang appstream

%clean
rm -rf $RPM_BUILD_ROOT

%post	-p /sbin/ldconfig
%postun	-p /sbin/ldconfig

%post	qt -p /sbin/ldconfig
%postun	qt -p /sbin/ldconfig

%files -f appstream.lang
%defattr(644,root,root,755)
%doc AUTHORS MAINTAINERS NEWS README.md RELEASE
%attr(755,root,root) %{_bindir}/appstreamcli
%attr(755,root,root) %{_libdir}/libappstream.so.*.*.*
%attr(755,root,root) %ghost %{_libdir}/libappstream.so.4
%{_libdir}/girepository-1.0/AppStream-1.0.typelib
%config(noreplace) %verify(not md5 mtime size) %{_sysconfdir}/appstream.conf
%dir %{_datadir}/metainfo
%{_datadir}/metainfo/org.freedesktop.appstream.cli.metainfo.xml
%if %{with apt}
/etc/apt/apt.conf.d/50appstream
%endif
%{_mandir}/man1/appstreamcli.1*

%files devel
%defattr(644,root,root,755)
%attr(755,root,root) %{_libdir}/libappstream.so
%{_datadir}/gir-1.0/AppStream-1.0.gir
%{_includedir}/appstream
%{_pkgconfigdir}/appstream.pc

%if %{with apidocs}
%files apidocs
%defattr(644,root,root,755)
%{_docdir}/appstream
%{_gtkdocdir}/appstream
%endif

%if %{with qt}
%files qt
%defattr(644,root,root,755)
%attr(755,root,root) %{_libdir}/libAppStreamQt.so.*.*.*
%attr(755,root,root) %ghost %{_libdir}/libAppStreamQt.so.2

%files qt-devel
%defattr(644,root,root,755)
%attr(755,root,root) %{_libdir}/libAppStreamQt.so
%{_includedir}/AppStreamQt
%{_libdir}/cmake/AppStreamQt
%endif

%files -n gettext-its-metainfo
%defattr(644,root,root,755)
%{_datadir}/gettext/its/metainfo.its
%{_datadir}/gettext/its/metainfo.loc

%if %{with vala}
%files -n vala-appstream
%defattr(644,root,root,755)
%{_datadir}/vala/vapi/appstream.deps
%{_datadir}/vala/vapi/appstream.vapi
%endif
%changelog
* Sat Dec 23 2017 PLD Linux Team <feedback@pld-linux.org>
- For complete changelog see: http://git.pld-linux.org/?p=packages/AppStream.git;a=log;h=master

* Sat Dec 23 2017 Jakub Bogusz <qboosh@pld-linux.org> 739d45a
- updated to 0.11.7; now uses meson to build
- added meson patch (fixes backslash conversion issue)

* Fri Jul 14 2017 Jakub Bogusz <qboosh@pld-linux.org> dd9620a
- updated to 0.11.1

* Wed May 10 2017 Jakub Bogusz <qboosh@pld-linux.org> 657143e
- updated to 0.11.0

* Sun Mar 12 2017 Jakub Bogusz <qboosh@pld-linux.org> 5b67432
- BR: Qt5Test-devel

* Sun Mar 12 2017 Jakub Bogusz <qboosh@pld-linux.org> 238c049
- updated to 0.10.6

* Tue Dec 27 2016 Jakub Bogusz <qboosh@pld-linux.org> 3b6d4ef
- updated to 0.10.5 (note: qt library API/ABI break)
- removed obsolete libstemmer patch

* Wed Oct 05 2016 Jakub Bogusz <qboosh@pld-linux.org> 7564e8a
- updated to 0.10.1 (note: new soname, changed metainfo dir)
- added libstemmer patch (adjust to libstemmer include dir in PLD)

* Tue Aug 23 2016 Jakub Bogusz <qboosh@pld-linux.org> cc61671
- updated to 0.9.8

* Sat Jun 25 2016 Jakub Bogusz <qboosh@pld-linux.org> 92bc25c
- updated to 0.9.6

* Tue Mar 29 2016 Jakub Bogusz <qboosh@pld-linux.org> 47dec53
- updated to 0.9.3

* Tue Mar 29 2016 Jakub Bogusz <qboosh@pld-linux.org> 1fe43c0
- its dir belongs to gettext now

* Mon Mar 28 2016 Elan Ruusamäe <glen@delfi.ee> 36752e9
- noarch vala subpackage

* Mon Mar 14 2016 Jakub Bogusz <qboosh@pld-linux.org> f496a6a
- updated to 0.9.2

* Sun Feb 21 2016 Jakub Bogusz <qboosh@pld-linux.org> 10308cd
- updated to 0.9.1
- added gettext-its-metainfo package with gettext support contrib files

* Sun Jan 24 2016 Jakub Bogusz <qboosh@pld-linux.org> b32aeca
- updated to 0.9.0 (note: new libappstream soname)

* Sun Nov 08 2015 Jakub Bogusz <qboosh@pld-linux.org> 9c78b34
- updated to 0.8.6
- removed obsolete cmake patch

* Fri Oct 16 2015 Jakub Bogusz <qboosh@pld-linux.org> 309888e
- updated to 0.8.5

* Fri Sep 11 2015 Jakub Bogusz <qboosh@pld-linux.org> c478a3e
- updated to 0.8.4
- qt4 is no longer supported

* Sat Mar 28 2015 Elan Ruusamäe <glen@delfi.ee> e119917
- noarch apidocs

* Thu Jan 29 2015 Jakub Bogusz <qboosh@pld-linux.org> 112490e
- updated to 0.8.0; now defaults to qt5

